@@ -17,7 +17,7 @@ def v7multi(symbols):
         df.set_index('symbol', inplace=True, drop=True)
         return df
     except Exception as e:
-        errorData = jsonData['error']
+        errorData = jsonData['quoteResponse']['error']
         return errorData
 
 
